@@ -19,6 +19,7 @@ from taf.exceptions import (
 )
 from taf.log import taf_logger
 from taf.utils import run
+from typing import Optional
 from .pygit import PyGitRepository
 
 EMPTY_TREE = "4b825dc642cb6eb9a060e54bf8d69288fbee4904"
@@ -31,7 +32,7 @@ class GitRepository:
         name=None,
         urls=None,
         custom=None,
-        default_branch="main",
+        default_branch=None,
         allow_unsafe=False,
         path=None,
         *args,
@@ -87,9 +88,11 @@ class GitRepository:
             self.path = self._validate_repo_path(path, None)
 
         self.urls = self._validate_urls(urls)
-        self.default_branch = default_branch
-        self.custom = custom or {}
         self.allow_unsafe = allow_unsafe
+        self.custom = custom or {}
+        if default_branch is None:
+            default_branch = self._determine_default_branch()
+        self.default_branch = default_branch
 
     _pygit = None
 
@@ -168,7 +171,7 @@ class GitRepository:
         try:
             return self.pygit.repo
         except Exception as e:
-            self._log_info(f"Unable to instantiate pygit2 repo due to error: {str(e)}")
+            self._log_debug(f"Unable to instantiate pygit2 repo due to error: {str(e)}")
             return None
 
     def _git(self, cmd, *args, **kwargs):
@@ -222,6 +225,30 @@ class GitRepository:
                 self._log_debug(log_success_msg)
         return result
 
+    def _get_default_branch_from_local(self) -> str:
+        try:
+            branch = self._git(
+                "symbolic-ref refs/remotes/origin/HEAD --short", reraise_error=True
+            )
+            return _local_branch_re.sub("", branch)
+        except GitError as e:
+            self._log_debug(f"Could not get remote HEAD at {self.path}: {e}")
+            pass
+        # NOTE: will not work if local repository is in a detached HEAD
+        branch = self._git("symbolic-ref HEAD --short", reraise_error=True)
+        return branch
+
+    def _get_default_branch_from_remote(self, url: str) -> str:
+        branch = self._git(
+            f"ls-remote --symref {url} HEAD",
+            log_error=True,
+            log_error_msg="Unable to get default branch from remote",
+            reraise_error=True,
+        )
+        branch = branch.split("\t", 1)[0]
+        branch = branch.split()[-1]
+        return _remote_branch_re.sub("", branch)
+
     def _log(self, log_func, message):
         log_func(self.log_template, self.log_prefix, message)
 
@@ -289,6 +316,13 @@ class GitRepository:
         self._log_debug(f"found the following commits: {', '.join(shas)}")
         return shas
 
+    def add_remote(self, upstream_name: str, upstream_url: str) -> None:
+        try:
+            self._git("remote add {} {}", upstream_name, upstream_url)
+        except GitError as e:
+            if "already exists" not in str(e):
+                raise
+
     def branches(self, remote=False, all=False, strip_remote=False):
         """Returns all branches."""
         repo = self.pygit_repo
@@ -485,20 +519,24 @@ class GitRepository:
         if not cloned:
             raise CloneRepoException(self)
 
+        if self.default_branch is None:
+            self.default_branch = self._determine_default_branch()
+
     def clone_or_pull(self, branches=None, only_fetch=False, **kwargs):
         """
         Clone or fetch the specified branch for the given repo.
         Return old and new HEAD.
         """
-        if branches is None:
-            branches = [self.default_branch]
-        self._log_debug(f"cloning or pulling branches {', '.join(branches)}")
 
         old_head = self.head_commit_sha()
         if old_head is None:
+            self._log_debug(f"cloning {self.name}")
             self._log_debug(f"old head sha is {old_head}")
             self.clone(**kwargs)
         else:
+            if branches is None:
+                branches = [self.default_branch]
+            self._log_debug(f"pulling branches {', '.join(branches)}")
             try:
                 for branch in branches:
                     if only_fetch:
@@ -654,6 +692,15 @@ class GitRepository:
         """Get commit sha of HEAD~{behind_head}"""
         return self._git("rev-parse HEAD~{}", behind_head)
 
+    def get_default_branch(self, url: Optional[str] = None) -> str:
+        """Get the default branch of the repository. If url is provided, return the
+        default branch from the remote. Otherwise, return the default
+        branch from the local repository."""
+        if url is not None:
+            url = url.strip()
+            return self._get_default_branch_from_remote(url)
+        return self._get_default_branch_from_local()
+
     def get_json(self, commit, path, raw=False):
         s = self.get_file(commit, path, raw=raw)
         return json.loads(s)
@@ -898,9 +945,18 @@ class GitRepository:
             for wt in worktrees
         }
 
-    def merge_commit(self, commit, fast_forward_only=False):
+    def merge_commit(
+        self, commit: str, fast_forward_only=False, check_if_merge_completed=False
+    ) -> bool:
         fast_forward_only_flag = "--ff-only" if fast_forward_only else ""
         self._git("merge {} {}", commit, fast_forward_only_flag, log_error=True)
+        if check_if_merge_completed:
+            try:
+                self._git("rev-parse -q --verify MERGE_HEAD")
+                return False
+            except GitError:
+                pass
+        return True
 
     def merge_branch(self, branch_name, allow_new_commit=False):
         if allow_new_commit:
@@ -935,8 +991,16 @@ class GitRepository:
             force_flag,
             branch,
             log_error=True,
+            reraise_error=True,
         )
 
+    def remove_remote(self, remote_name: str) -> None:
+        try:
+            self._git("remote remove {}", remote_name)
+        except GitError as e:
+            if "No such remote" not in str(e):
+                raise
+
     def rename_branch(self, old_name, new_name):
         self._git("branch -m {} {}", old_name, new_name)
 
@@ -1009,6 +1073,30 @@ class GitRepository:
         except Exception:
             return None
 
+    def _determine_default_branch(self) -> Optional[str]:
+        """Determine the default branch of the repository"""
+        # try to get the default branch from the local repository
+        errors = []
+        try:
+            return self.get_default_branch()
+        except GitError as e:
+            errors.append(e)
+            pass
+
+        # if the local repository does not exist or doesn't have a default branch, try to get the default branch from remote
+        if self.urls:
+            for url in self.urls:
+                try:
+                    return self.get_default_branch(url)
+                except GitError as e:
+                    errors.append(e)
+                    pass
+
+        self._log_debug(
+            f"Cannot determine default branch with git -C at {self.path}: {errors}"
+        )
+        return None
+
     def _validate_repo_name(self, name):
         """Ensure the repo name is not malicious"""
         match = _repo_name_re.match(name)
@@ -1072,6 +1160,10 @@ class GitRepository:
         return urls
 
 
+_remote_branch_re = re.compile(r"^(refs/heads/)")
+
+_local_branch_re = re.compile(r"^(origin/)")
+
 _repo_name_re = re.compile(r"^\w[\w_-]*/\w[\w_-]*$")
 
 _http_fttp_url = re.compile(
