@@ -1,5 +1,7 @@
 import click
+import json
 import taf.developer_tool as developer_tool
+from taf.exceptions import YubikeyError
 
 
 def attach_to_group(group):
@@ -8,6 +10,24 @@ def attach_to_group(group):
     def yubikey():
         pass
 
+    @yubikey.command()
+    @click.argument("pin")
+    def check_pin(pin):
+        """Checks if the specified pin is valid"""
+        try:
+            from taf.yubikey import is_valid_pin
+            valid, retries = is_valid_pin(pin)
+            inserted = True
+        except YubikeyError:
+            valid = False
+            inserted = False
+            retries = None
+        print(json.dumps({
+            "pin": valid,
+            "retries": retries,
+            "inserted": inserted
+        }))
+
     @yubikey.command()
     @click.option("--output", help="File to which the exported public key will be written. "
                   "The result will be written to the console if path is not specified")
